@@ -13,8 +13,8 @@ class test_ETreeRenderer(unittest.TestCase):
     def test_single_level(self):
         tree = Tree()
         root = tree.a('Here', href='url', title='A Title')
-        actual = root.render('etree', as_root=True)
-        result = e.fromstring(actual)
+        actual = root.render('etree')
+        result = actual.find('a')
 
         self.assertEqual(result.tag, 'a')
         self.assertEqual(result.attrib['href'], 'url')
@@ -28,10 +28,9 @@ class test_ETreeRenderer(unittest.TestCase):
             two.third('Three', level=3)
         root.fourth('four', level=2)
 
-        actual = root.render('etree', as_root=True)
 
         # Parse the xml and break it into pieces to assert.
-        result = e.fromstring(actual)
+        result = root.render('etree').find('root')
         second = result.find('second')
         third = result.find('.//third')
         fourth = result.find('fourth')
