@@ -3,7 +3,7 @@ try:
 except ImportError:
     import unittest
 
-from datatree.node import Tree
+from datatree import Tree
 
 class test_Tree(unittest.TestCase):
     pass # TODO: Revisit. Does this need its own tests?
